==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/uk.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Ваші дії",
    "Personal activity feed for %s" : "Персональна стрічка оновлень для %s",
    "Your feed URL is invalid" : "Ваше посилання новинної стрічки неправильна",
    "Your settings have been updated." : "Налаштування оновлені.",
    "Mail" : "Пошта",
    "Stream" : "Потік",
    "Activities" : "Активність",
    "This stream will show events like additions, changes & shares" : "У цьому потоці будуть показані події, на кшталт доповнення, зміни та поширення",
    "There are no events for this filter" : "За цим фільтром події відсутні",
    "Activity notification" : "Повідомлення про події",
    "All Activities" : "Всі дії",
    "Activities by you" : "Ваші дії",
    "Activities by others" : "Дії інших користувачів",
    "\"remote user\"" : "\"віддалений користувач\"",
    "in %s" : "в %s",
    "%s and %s" : "%s і %s",
    ", " : ",",
    "_%s and %n more_::_%s and %n more_" : [" %s і %n ще"," %s і %n ще","%s і %n ще"],
    "Hello %s," : "Привіт %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["1","кілька","* та ще %n"],
    "Notifications" : "Сповіщення",
    "List your own actions in the stream" : "Показувати мої дії в потоці",
    "Notify about your own actions via email" : "Повідомляти про мої дії по email",
    "You need to set up your email address before you can receive notification emails." : "Для отримання повідомлень вкажіть свій e-mail в особистих налаштуваннях.",
    "Send emails:" : "Відправляти електронні повідомлення:",
    "Hourly" : "Щогодини",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Activity feed" : "Стрічка оновлень",
    "Enable RSS feed" : "Активувати RSS стрічку",
    "No activity yet" : "Поки що активність відсутня",
    "No more events to load" : "Більше немає подій для завантаження",
    "Files" : "Файли"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/uk.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Ваші дії",
    "Personal activity feed for %s" : "Персональна стрічка оновлень для %s",
    "Your feed URL is invalid" : "Ваше посилання новинної стрічки неправильна",
    "Your settings have been updated." : "Налаштування оновлені.",
    "Mail" : "Пошта",
    "Stream" : "Потік",
    "Activities" : "Активність",
    "Error loading activities" : "Помилка завантаження подій",
    "No activities" : "Активність відсутня",
    ", " : ",",
    "{parameterList} and {lastParameter}" : "{parameterList} та {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} та {linkStart}%n ще{linkEnd}","{parameterList} та {linkStart}%n ще{linkEnd}","{parameterList} та {linkStart}%n ще{linkEnd}"],
    "in {directory}" : "у {directory}",
    "This stream will show events like additions, changes & shares" : "У цьому потоці будуть показані події, на кшталт доповнення, зміни та поширення",
    "There are no events for this filter" : "За цим фільтром події відсутні",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "\"remote user\"" : "\"віддалений користувач\"",
    "Activity notification" : "Повідомлення про події",
    "All Activities" : "Всі дії",
    "Activities by you" : "Ваші дії",
    "Activities by others" : "Дії інших користувачів",
    "%s and %s" : "%s і %s",
    "Hello %s," : "Привіт %s,",
    "You are receiving this email because the following things happened at %s" : "Ви отримали це повідомлення, оскільки на %s відбувається наступне",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["1","кілька","* та ще %n"],
    "List your own actions in the stream" : "Показувати мої дії в потоці",
    "Notify about your own actions via email" : "Повідомляти про мої дії по email",
    "You need to set up your email address before you can receive notification emails." : "Для отримання повідомлень вкажіть свій e-mail в особистих налаштуваннях.",
    "Send emails:" : "Відправляти електронні повідомлення:",
    "Hourly" : "Щогодини",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Activity feed" : "Стрічка оновлень",
    "Enable RSS feed" : "Активувати RSS стрічку",
    "No activity yet" : "Поки що активність відсутня",
    "No more events to load" : "Більше немає подій для завантаження",
    "Files" : "Файли"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
